@@ -1,6 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
-# Copyright (C) 2008-2019, Roland van Ipenburg
-package Date::Extract::P800Picture::Exceptions v1.1.2;
+# Copyright (C) 2008-2020, Roland van Ipenburg
+package Date::Extract::P800Picture::Exceptions v1.1.3;
 use strict;
 use warnings;
 
@@ -26,7 +26,7 @@ Date::Extract::P800Picture::Exceptions - exceptions.
 
 =head1 VERSION
 
-This document describes Date::Extract::P800Picture::Exceptions version v1.1.2.
+This document describes Date::Extract::P800Picture::Exceptions version v1.1.3.
 
 =head1 SYNOPSIS
 
@@ -60,11 +60,11 @@ https://rt.cpan.org/Dist/Display.html?Queue=Date-Extract-P800Picture>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
+Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2008-2019, Roland van Ipenburg
+Copyright (C) 2008-2020, Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
